@@ -15,7 +15,7 @@ pascal_per_millibar = 100
 seconds_in_hour = 3600
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.5.2'
+jaws_version = '0.5.3'
 
 ###############################################################################
 
@@ -157,7 +157,10 @@ def load_dataset_attributes_gcnet_qltyctrl(name, ds):
                 if key2 == 'type':
                     pass
                 else:
-                    ds[key1].attrs = value2.items()
+                    try:
+                        ds[key1].attrs = value2.items()
+                    except KeyError:
+                        pass
 
 
 def get_encoding(name, fillvalue, comp_level):
